<p align="center">
  <a href="https://github.com/Naruno/Naruno">
    <img src="https://naruno.org/goaxisar/2023/03/transparant-logo-1.png" alt="Logo" width="150" height="150">
  </a>

  <h3 align="center">Naruno</h3>

  <p align="center">
    Upgrade to new internet !
    <br />
    <a href="https://naruno.org/"><strong>Explore the website »</strong></a>
    <br />
    </p>
    <br>
    <p align="center">
    <a href="https://docs.naruno.org/getting-started/installations/downloads.html#dowloads-for-users">
    <img src="https://img.shields.io/badge/Android-3DDC84?style=for-the-badge&logo=android&logoColor=white" alt="android">
    </a>
    <a href="https://docs.naruno.org/getting-started/installations/downloads.html#dowloads-for-users">
   <img src="https://img.shields.io/badge/Linux-FCC624?style=for-the-badge&logo=linux&logoColor=black" alt="linux">
   </a>
   <a href="https://docs.naruno.org/getting-started/installations/downloads.html#dowloads-for-users">
   <img src="https://img.shields.io/badge/mac%20os-000000?style=for-the-badge&logo=apple&logoColor=white" alt="macos">
   </a>
   <a href="https://docs.naruno.org/getting-started/installations/downloads.html#dowloads-for-users">
   <img src="https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white" alt="windows">
   </a>
  <br> <br>

  </p>
  <p align="center">
  <img src="https://img.shields.io/github/v/release/Naruno/Naruno" alt="release_version">
  </p>
  <p align="center">
  <a href="https://www.python.org/">
  <img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg" alt="Made_with_python">
  </a>
  .
  <img src="https://img.shields.io/github/repo-size/Naruno/Naruno" alt="repo_size">
  .
  <img  src="https://img.shields.io/tokei/lines/github/Naruno/Naruno" alt="total_lines">
  .
  <img src="https://static.pepy.tech/personalized-badge/naruno?period=total&units=international_system&left_color=grey&right_color=blue&left_text=PyPI%20Downloads" alt="pypi_downloads">
  </p>

  <p align="center">
  <a href="https://www.codefactor.io/repository/github/naruno/naruno"><img src="https://www.codefactor.io/repository/github/naruno/naruno/badge" alt="CodeFactor" /></a>
  .
  <a href="https://codecov.io/gh/Naruno/Naruno" >
   <img src="https://codecov.io/gh/Naruno/Naruno/branch/master/graph/badge.svg?token=YT9JQFBIPN"/>
   </a>
  </p>

  <p align="center">
    <a href="https://github.com/Naruno/Naruno/actions/workflows/codeql-analysis.yml">
  <img src="https://github.com/Naruno/Naruno/actions/workflows/codeql-analysis.yml/badge.svg" alt="CodeQL">
  </a>
  .
  <a href="https://codebeat.co/projects/github-com-naruno-naruno-master"><img alt="codebeat badge" src="https://codebeat.co/badges/1365faa1-70b1-41d9-80df-4ee49f798e1a" /></a>
  .
  <a href="https://www.codacy.com/gh/Naruno/Naruno/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Naruno/Naruno&amp;utm_campaign=Badge_Grade"><img  alt="codacy badge" src="https://app.codacy.com/project/badge/Grade/b6a1e33964ac4759bc36a02763ca9bcb"/></a>
  </p>

  <p align="center">
  <a href="https://codescene.io/projects/36313"><img src="https://codescene.io/projects/36313/status-badges/code-health" alt="Code Health"></a>
  .
  <a href="https://codescene.io/projects/36313"><img src="https://codescene.io/projects/36313/status-badges/system-mastery" alt="System Mastery"></a>
  .
  <a href="https://codescene.io/projects/36313"><img src="https://codescene.io/projects/36313/status-badges/missed-goals" alt="Missed Goals"></a>
  </p>

  <p align="center">
   <a href="https://github.com/Naruno/Naruno/actions/workflows/tests.yml">
  <img src="https://github.com/Naruno/Naruno/actions/workflows/tests.yml/badge.svg" alt="tests">
  <a/>
     .
   <a href="https://github.com/Naruno/Naruno/actions/workflows/builds.yml">
  <img src="https://github.com/Naruno/Naruno/actions/workflows/builds.yml/badge.svg" alt="builds">
  <a/>
  .
   <a href="https://github.com/Naruno/Naruno/actions/workflows/deploys.yml">
  <img src="https://github.com/Naruno/Naruno/actions/workflows/deploys.yml/badge.svg" alt="deploys">
  <a/>
  </p>
  <p align="center">
  <a href="https://cloudback.it">
  <img src="https://cloudback.it/badge/Naruno/Naruno" alt="backups">
  </a>
  </p>

  <p align="center">
   <a href="https://github.com/features/copilot/">
  <img src="https://img.shields.io/badge/With-Copilot-292242" alt="with_copilot">
  <a/>
  </p>

# Introducing

Naruno is a lightning-fast, secure, and scalable blockchain that is able to create transaction proofs and verification via raw data and timestamp. We remove the archive nodes and lazy web3 integrations. With Naruno everyone can get the proof (5-10MB) of their transactions via their nodes and after everyone can use in another node for verification the raw data and timestamp. Also you can integrate your web3 applications with 4 code lines (just python for now) via our remote app system.

- World Wide First In Node Level Transaction Proof Mechanism (Revulation to archive nodes)

- FBA Consensus Protocol
- 7 Second Block Time (Reducible to 3s)
- 10k Potential TPS

- Totaly New Infrastructure (100% Python)
- Already Automated Workflows
- 100% Code Coverage with unit, functional and stability tests
- Already distribute CLI, API and GUI in Android, Windows, MacOS and Linux

- Mobile Master Node Support
- Two Web3 Integration way as Embedded App (Naruno App Engine) and Remote App (Naruno API)

- And more...

\*Some features will be adjusted in stable release.

The software is written in **PEP8** format and **only** needs dependent libraries for GUI panel. Naruno software, designed with a focus on the **community on the Github platform**, In addition, **Stability**, **Functional** and **Unit** tests of all systems are ready and automated. It also has various structures for **automatic setup of test environments**. It is fully compatible with **Git code management system** and **Agile mindset**.

# Documents

Our documents are available in the [docs](https://github.com/Naruno/Naruno/tree/master/docs) folder and [this](https://docs.naruno.org/) website.

# Contribute

Naruno is a completely community driven project, you can contribute in any way if you follow the [guidelines](https://github.com/Naruno/Naruno/blob/master/CONTRIBUTING.md) and [terms](https://github.com/Naruno/Naruno/blob/master/CODE_OF_CONDUCT.md).

<br />

# Analysis && Statistics

## Github Statistics

<p align="center">

  <p align="center">
    <img src="https://img.shields.io/github/stars/Naruno/Naruno?style=social" alt="Repo_stars">
  .
  <img src="https://img.shields.io/github/forks/Naruno/Naruno?style=social" alt="Repo_forks">
    <br />
  <img src="https://img.shields.io/github/issues-raw/Naruno/Naruno" alt="Open_issues">
  .
  <img src="https://img.shields.io/github/issues-closed-raw/Naruno/Naruno" alt="Closed_issues">
    <br />
  <img src="https://img.shields.io/github/issues-pr-raw/Naruno/Naruno" alt="Open_pull_requests">
  .
    <img src="https://img.shields.io/github/issues-pr-closed-raw/Naruno/Naruno" alt="Closed_pull_requests">

<br />
  </p>
</p>

# Sponsors

<p align="center">
   <a href="https://narin.net.tr/">
  <img src="https://naruno.org/goaxisar/2023/03/narinhosting340x120.png" alt="web_infrastructure_sponsor">
  <a/>
  </p>

<br/>
